==> 4.1.0.tar.gz: lib/src/utils/translations.dart <==
import 'dart:async';
import 'dart:convert';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart' show rootBundle;

class Translations {
  Translations(this.locale);

  final Locale locale;
  static Map<dynamic, dynamic>? _localizedValues;

  static Translations? of(BuildContext context) {
    return Localizations.of<Translations>(context, Translations);
  }

  String text(String key) {
    return _localizedValues![key] ?? '** $key not found';
  }

  static Future<Translations> load(Locale locale) async {
    //TODO: Fix language gl, ca by country
    Translations translations = new Translations(locale);
    try {
      String jsonContent = await rootBundle.loadString(
          "packages/dcoupon_sdk_flutter_package/lib/assets/i18n/${locale.languageCode}.json");
      _localizedValues = json.decode(jsonContent);
    } catch (ex) {
      print("Translations.load() error: " + ex.toString());
      String jsonContent = await rootBundle.loadString(
          "packages/dcoupon_sdk_flutter_package/lib/assets/i18n/es.json");
      _localizedValues = json.decode(jsonContent);
    }
    return translations;
  }

  get currentLanguage => locale.languageCode;
}

class TranslationsDelegate extends LocalizationsDelegate<Translations> {
  const TranslationsDelegate();

  @override
  bool isSupported(Locale locale) => ['en', 'es'].contains(locale.languageCode);

  @override
  Future<Translations> load(Locale locale) => Translations.load(locale);

  @override
  bool shouldReload(TranslationsDelegate old) => false;
}

==> 4.4.0.tar.gz: lib/src/utils/translations.dart <==
import 'dart:async';
import 'dart:convert';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart' show rootBundle;

class TranslationsDelegate extends LocalizationsDelegate<Translations> {
  const TranslationsDelegate();

  List<Locale> get supportedLocales {
    //MUST update Info tab on iOS Runner project according to this
    return const <Locale>[
      const Locale('en', 'EN'),
      const Locale('es', 'ES'),
      const Locale('pt', ''),
    ];
  }

  @override
  bool isSupported(Locale locale) {
    for (var supportedLocale in supportedLocales) {
      if (supportedLocale.languageCode == locale.languageCode) {
        return true;
      }
    }
    return false;
  }

  @override
  Future<Translations> load(Locale locale) => Translations.load(locale);

  @override
  bool shouldReload(TranslationsDelegate old) => false;
}

class Translations {
  Translations(this.locale);

  static const TranslationsDelegate delegate = TranslationsDelegate();

  final Locale locale;
  static Map<dynamic, dynamic>? _localizedValues;

  static Translations? of(BuildContext context) {
    return Localizations.of<Translations>(context, Translations);
  }

  String text(String key) {
    return _localizedValues![key] ?? '** $key not found';
  }

  static Future<Translations> load(Locale locale) async {
    //TODO: Fix language gl, ca by country
    Translations translations = new Translations(locale);
    try {
      String jsonContent = await rootBundle.loadString(
          "packages/dcoupon_sdk_flutter_package/lib/assets/i18n/${locale.languageCode}.json");
      _localizedValues = json.decode(jsonContent);
    } catch (ex) {
      print("Translations.load() error: " + ex.toString());
      String jsonContent = await rootBundle.loadString(
          "packages/dcoupon_sdk_flutter_package/lib/assets/i18n/es.json");
      _localizedValues = json.decode(jsonContent);
    }
    return translations;
  }

  get currentLanguage => locale.languageCode;
}
